<?php
/**
 * Minimaler Controller
 */
class Controller {
	// instanz des controlelrs (singleton)
	private static $instance;
	
	// privater konstruktor (singleton)
	private function __construct() {
	}
	
	public static function getInstance() {
		if (self::$instance == null) {
			self::$instance = new Controller();
		}
		
		return self::$instance;
	}
	
	/**
	 * erzeugen einer url zu einer action
	 */
	public function makeUrl($actionName, $params = array()) {
		$url = 'index.php?action=' . $actionName;
		
		foreach ($params as $key => $value) {
			$url .= '&amp;' . urlencode($key) . '=' . urlencode($value);
		}
		
		return $url;
	}
	
	/**
	 * erzeugen einer action mit (minimaler) fehlerbehandlung
	 */
	public function createAction($actionName) {
		if (! class_exists($actionName)) {
			$action = new ActionNotFoundAction();
		} else {
			$action = new $actionName();
		}
		
		if (! $action instanceof Action) {
			$action = new ActionNotFoundAction();
		}
		
		return $action;
	}
}

function __autoload($className) {
	$potentialLocations = array(
		'classes/' . $className . '.class.php',
		'classes/' . $className . '.interface.php',
		'actions/' . $className . '.class.php',
		'actions/' . $className . '.interface.php',
		'application/' . $className . '.class.php',
		'application/' . $className . '.interface.php',
	);
	
	foreach($potentialLocations as $location) {
		if (file_exists($location)) {
			include $location;
			return true;
		}
	}
	
	return false;
}

?>